/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as I, createVNode as d } from "vue";
import { validatePackage as u, guid as c, getRef as p, setRef as f, templateRendering as m, getListeners as l, Keys as a, canUseDOM as h } from "@progress/kendo-vue-common";
import { EMPTY_ID as s, ZERO_LEVEL_ZERO_ITEM_ID as o, getDirectParentId as v, getItemById as n, getRootParentId as b, isIdEmptyOrZeroLevel as r } from "../utils/itemsIdsUtils.mjs";
import { prepareInputItemsForInternalWork as g } from "../utils/prepareInputItemsForInternalWork.mjs";
import { getNewItemIdUponKeyboardNavigation as R } from "../utils/getNewItemIdUponKeyboardNavigation.mjs";
import { getHoverOpenDelay as H, getHoverCloseDelay as O } from "../utils/hoverDelay.mjs";
import { DirectionHolder as k } from "../utils/DirectionHolder.mjs";
import { MouseOverHandler as C } from "../utils/MouseOverHandler.mjs";
import { packageMetadata as D } from "../../package-metadata.mjs";
import { MenuItemInternalsList as L } from "./MenuItemInternal.mjs";
const N = /* @__PURE__ */ I({
  name: "KendoMenu",
  props: {
    vertical: {
      type: Boolean,
      default: !1
    },
    items: Array,
    dir: String,
    hoverOpenDelay: {
      type: Number,
      default: void 0
    },
    hoverCloseDelay: {
      type: Number,
      default: void 0
    },
    openOnClick: Boolean,
    itemRender: [String, Object, Function],
    linkRender: [String, Object, Function],
    customCloseItemIds: Array
  },
  created() {
    u(D), this.mouseOverHandler = new C(this.$props.openOnClick, this.reset, this.onItemMouseOver), this.guid = c(), this.directionHolder = new k(), this.inputItems = [], this.currentItems = [];
  },
  mounted() {
    this.isFirstRender = !1, this.menuWrapperEl = p(this, "menuWrapper");
  },
  updated() {
    this.mouseOverHandler.OpenOnClick = this.$props.openOnClick;
  },
  unmounted() {
    this.clearItemHoverAndLeaveRequestsIfApplicable();
  },
  data() {
    return {
      focusedItemId: s,
      hoveredItemId: s,
      tabbableItemId: o,
      isFirstRender: !0
    };
  },
  computed: {
    menuClassName() {
      return {
        "k-widget": !0,
        "k-reset": !0,
        "k-header": !0,
        "k-menu": !0,
        "k-menu-horizontal": !this.$props.vertical,
        "k-menu-vertical": this.$props.vertical
      };
    }
  },
  render() {
    this.prepareItems(), this.isFirstRender || this.directionHolder.setIsDirectionRightToLeft(this.checkIsDirectionRightToLeft());
    let e = this.hoveredItemId ? this.hoveredItemId : this.focusedItemId ? v(this.focusedItemId) : s;
    return d("div", {
      class: this.getMenuWrapperClassName(),
      ref: f(this, "menuWrapper")
    }, [d(L, {
      class: this.menuClassName,
      "aria-orientation": this.$props.vertical ? "vertical" : void 0,
      items: this.currentItems,
      isMenuVertical: this.$props.vertical,
      isDirectionRightToLeft: this.directionHolder.getIsDirectionRightToLeft(),
      focusedItemId: this.focusedItemId,
      lastItemIdToBeOpened: e,
      tabbableItemId: this.tabbableItemId,
      itemRender: m.call(this, this.$props.itemRender, l.call(this)),
      linkRender: m.call(this, this.$props.linkRender, l.call(this)),
      menuGuid: this.guid,
      onMouseleave: this.onItemMouseLeave,
      onMouseover: this.onItemMouseOver,
      onMousedown: this.onItemMouseDown,
      onKeydown: this.onKeyDown,
      onFocus: this.onItemFocus,
      onClick: this.onItemClick,
      onBlur: this.onItemBlur,
      originalItemNeeded: this.getInputItem
    }, null)]);
  },
  methods: {
    reset() {
      this.clearItemHoverAndLeaveRequestsIfApplicable(), this.focusedItemId = s, this.hoveredItemId = s, this.tabbableItemId = o;
    },
    onKeyDown(e) {
      if (this.focusedItemId !== s) {
        const t = n(this.focusedItemId, this.currentItems), i = R(this.currentItems, t.id, e.keyCode, e.key, this.$props.vertical, this.directionHolder.getIsDirectionRightToLeft());
        t.id !== i && (e.preventDefault(), this.setFocusedItemId(i)), (e.keyCode === a.enter || e.keyCode === a.space) && !t.disabled && (this.mouseOverHandler.handleItemSelectedViaKeyboard(), this.dispatchSelectEventIfWired(e, t.id), !e.defaultPrevented && t.items.length === 0 && t.url && h && window.location.assign(t.url));
      }
    },
    onItemMouseOver(e) {
      this.mouseOverHandler.IsMouseOverEnabled && (this.clearItemHoverAndLeaveRequestsIfApplicable(), this.itemHoverRequest = window.setTimeout(() => {
        this.setHoveredItemId(e), this.itemHoverRequest = null;
      }, H({
        ...this.$props
      })));
    },
    onItemMouseLeave(e) {
      this.mouseOverHandler.IsMouseOverEnabled && this.isItemWithDefaultClose(e) && (this.clearItemHoverAndLeaveRequestsIfApplicable(), this.itemLeaveRequest = window.setTimeout(() => {
        this.setHoveredItemId(s), this.itemLeaveRequest = null;
      }, O({
        ...this.$props
      })));
    },
    onItemMouseDown() {
      this.mouseOverHandler.handleItemMouseDown();
    },
    onItemFocus(e) {
      this.setFocusedItemId(e), this.mouseOverHandler.handleItemFocus();
    },
    onItemClick(e, t) {
      const i = n(t, this.currentItems);
      i.disabled || (this.setFocusedItemId(t), this.mouseOverHandler.handleItemClick(t, this.isItemWithDefaultClose(t)), this.dispatchSelectEventIfWired(e, t), !e.defaultPrevented && i.url && h && window.location.assign(i.url));
    },
    onItemBlur(e) {
      this.isItemWithDefaultClose(e) && this.setFocusedItemId(s);
    },
    getInputItem(e) {
      return n(e, this.inputItems);
    },
    setFocusedItemId(e) {
      const t = e === s ? this.tabbableItemId : b(e), i = e === s || r(this.hoveredItemId) && r(e) ? this.hoveredItemId : s;
      this.hoveredItemId = i, this.focusedItemId = e, this.tabbableItemId = t;
    },
    setHoveredItemId(e) {
      r(e) && r(this.focusedItemId) ? this.hoveredItemId = e : (this.hoveredItemId = e, this.focusedItemId = s, this.tabbableItemId = o);
    },
    getMenuWrapperClassName() {
      return {
        "k-rtl": this.directionHolder.getIsDirectionRightToLeft()
      };
    },
    clearItemHoverAndLeaveRequestsIfApplicable() {
      this.itemHoverRequest && (clearTimeout(this.itemHoverRequest), this.itemHoverRequest = null), this.itemLeaveRequest && (clearTimeout(this.itemLeaveRequest), this.itemLeaveRequest = null);
    },
    isItemWithDefaultClose(e) {
      return !this.$props.customCloseItemIds || this.$props.customCloseItemIds.indexOf(e) === -1;
    },
    checkIsDirectionRightToLeft() {
      return this.$props.dir !== void 0 ? this.$props.dir === "rtl" : this.menuWrapperEl && getComputedStyle(this.menuWrapperEl).direction === "rtl";
    },
    prepareItems() {
      const {
        items: e,
        inputItems: t
      } = g.call(this, this.$props.items);
      this.currentItems = e, this.inputItems = t;
    },
    dispatchSelectEventIfWired(e, t) {
      this.$emit("select", {
        event: e,
        compontent: this,
        item: this.getInputItem(t),
        itemId: t
      });
    }
  }
});
export {
  N as Menu
};
